#include <stdio.h>
#include <string.h>
#include <vector>
#include <unordered_map>

#define NMax 100000
#define VMax 1050000
#define MexMax 35

using namespace std;

FILE *fin = fopen("game.in", "rt");
FILE *fout = fopen("game.out", "wt");

int t, c, n, a[NMax]; // input
int pbs[VMax]; // prime -> bit set
int mex[VMax]; // bit set -> mex value
vector<int> mexes; // all nim piles
int umex[MexMax]; // used mex values
int bigFact[VMax]; // biggest factor of i

void eratostene() {
	int i, j, nr = 1;
	for (int i = 0; i < VMax; i += 2) {
		bigFact[i] = 2;
	}
	for (i = 3; i < VMax; i += 2) {
		if (bigFact[i] == 0) {
			for (j = 3 * i; j <= VMax; j += i << 1) {
				bigFact[j] = i;
			}
		}
	}
}

int decomposeFactor(int &number, int p) {
	int pwr = 0;
	while (number % p == 0) {
		number /= p;
		pwr++;
	}
	return pwr;
}

void decompose(int number) {

	while (bigFact[number] != 0) {
		int fact = bigFact[number];
		int pwr = decomposeFactor(number, fact);
		pbs[fact] |= (1 << (pwr - 1));
	}
	if (number > 1) {
		pbs[number] |= 1;
	}
}

int shiftBitSet(int bitSet, int k) {
	int nbs = (bitSet & ((1 << (k - 1)) - 1));
	nbs |= (bitSet >> k);
	return nbs;
}

int findMex(int bitSet){	
	if (mex[bitSet] != -1) {
		return mex[bitSet]; // known already
	} else {
		for (int k = 1, nbs = (bitSet >> 1); bitSet >= (1 << (k-1)); k++, nbs = shiftBitSet(bitSet, k)) {
			findMex(nbs);
		} // separate second for because umex is global
		for (int k = 1, nbs = (bitSet >> 1); bitSet >= (1 << (k-1)); k++, nbs = shiftBitSet(bitSet, k)) {
			umex[findMex(nbs)] = bitSet;
		}
		int i;
		for (i = 0; umex[i] == bitSet; i++);
		mex[bitSet] = i; // m(inimal) ex(clusive)
	}
}

void addExponentFreq(int prime, int sgn) {
	for (int k = 1, nbs = (pbs[prime] >> 1); pbs[prime] >= (1 << (k-1)); k++, nbs = shiftBitSet(pbs[prime], k)) {
		umex[mex[pbs[prime]] ^ mex[nbs]] += sgn;
	}
}

int main() {

	fscanf(fin, "%d %d", &t, &c);
	
	mex[0] = 0;
	for (int i = 1; i < VMax; i++) {
		mex[i] = -1;
	}
	for (int i = 1; i < VMax; i++) {
		findMex(i);
	}

	eratostene();

	while (t--) {
		memset(pbs, 0, sizeof(pbs));
		memset(umex, 0, sizeof(umex));
		fscanf(fin, "%d", &n);
		for (int i = 0; i < n; i++) {
			fscanf(fin, "%d", &a[i]);
			decompose(a[i]); // for all a[i] prime factors p^k will add {k} to pbs[p]
		}
		// now I have only bitsets
		int xsum = 0;
		for (int p = 2; p < VMax; p++) if (pbs[p]) {
			xsum ^= mex[pbs[p]];
			//fprintf(fout, "p %d bs %d mx %d\n", p, pbs[p], mex[pbs[p]]);
		}

		if (xsum) {			
			int aliceMoves = 0;
			for (int p = 2; p < VMax; p++) if (pbs[p]) { // any prime for Alice
				for (int k = 1, nbs = (pbs[p] >> 1); pbs[p] >= (1 << (k-1)); k++, nbs = shiftBitSet(pbs[p], k)) { // any exponent for Alice

					if ((xsum ^ mex[pbs[p]] ^ mex[nbs]) == 0) {
						aliceMoves++;
						//printf("alice can move: %d %d\n", p, k);
					} else {
						//printf("alice can't move: %d %d\n", p, k);
					}
				}
			}
			if (c == 1) {
				fprintf(fout, "Alice\n");
			} else {
				fprintf(fout, "%d\n", aliceMoves);
			}
		} else {
			// compute: umex[i] = how many ways to add i to xsum
			memset(umex, 0, sizeof(umex));
			for (int p = 2; p < VMax; p++) if (pbs[p]) {
				addExponentFreq(p, +1);
			}

			int bobMoves = 0;
			for (int p = 2; p < VMax; p++) if (pbs[p]) { // any prime for Bob
				int bitSet = pbs[p];
				addExponentFreq(p, -1); // temporary remove p from counters

				for (int k = 1, nbs = (bitSet >> 1); bitSet >= (1 << (k-1)); k++, nbs = shiftBitSet(bitSet, k)) { // any exponent for Bob
					int possible = 0;
					
					// is it possible that Alice moved using same prime p?
					// this can be reduced to O(1)
					for (int ka = 1; bitSet >= (1 << (k + ka-1)); ka++) { // any exponent for Alice
						if ((xsum ^ mex[bitSet] ^ mex[shiftBitSet(shiftBitSet(bitSet, ka), k)]) == 0) {
						//if ((xsum ^ mex[bitSet] ^ mex[shiftBitSet(nbs, ka)]) == 0) {
							possible = 1; // yes
						}
					}

					// or any other prime?
					int newXsum = (xsum ^ mex[bitSet] ^ mex[nbs]); // applied Bob's move
					int excludePrimeP = 0;
					
					if (possible || umex[newXsum]) {
						bobMoves++;
						//printf("Bob can move %d %d\n", p, k);
					}
				}
				addExponentFreq(p, +1); // add p back
			}
			if (c == 1) {
				fprintf(fout, "Bob\n");
			} else {
				fprintf(fout, "%d\n", bobMoves);
			}
		}
	}

	fclose(fin);
	fclose(fout);
	return 0;
}
